# Instructions

#### This is our test project.
#### Please install this package
```
pip install functions-by-darimco
```

#### You can also install older packages
```
pip install functions-by-darimco==VERSION_NUMBER
```